{% extends 'generic/object.html' %}
{% load helpers %}
{% load plugins %}
{% load render_table from django_tables2 %}

{% block content %}
<div class="row mb-3">
  <div class="col col-md-6">
    <div class="card">
      <h5 class="card-header">Application System</h5>
      <div class="card-body">
        <table class="table table-hover attr-table">
          <tr>
            <th scope="row">Name</th>
            <td>{{ object.name }}</td>
          </tr>
          <tr>
            <th scope="row">Slug</th>
            <td>{{ object.slug }}</td>
          </tr>
          <tr>
            <th scope="row">Description</th>
            <td>{{ object.description }}</td>
          </tr>
        </table>
      </div>
    </div>
    {% include 'inc/panels/custom_fields.html' %}
  </div>
  <div class="col col-md-6">
    {% include 'inc/panels/tags.html' %} 
    {% include 'inc/panels/comments.html' %}
  </div>
</div>
<div class="row mb-3">
  <div class="col col-md-12">
    <div class="card">
      <h5 class="card-header">Assignments</h5>
      <div class="card-body table-responsive">
        {% render_table assignments_table 'inc/table.html' %}
      </div>
    </div>
    {% plugin_full_width_page object %}
  </div>
</div>
{% endblock content %}
